pub struct TyphoonPlugin;Trait Implementations
Sourceimpl KorokPlugin for TyphoonPlugin
impl KorokPlugin for TyphoonPlugin
fn on_initialized(&self, visitable: &mut dyn KorokVisitable) -> CodamaResult<()>
fn on_fields_set(&self, visitable: &mut dyn KorokVisitable) -> CodamaResult<()>
fn on_program_items_set( &self, visitable: &mut dyn KorokVisitable, ) -> CodamaResult<()>
fn on_root_node_set( &self, visitable: &mut dyn KorokVisitable, ) -> CodamaResult<()>
Sourcefn resolve_type_directive(
&self,
_directive: &ResolvableDirective,
_resolver: &dyn DirectiveResolver,
) -> Option<Result<RegisteredTypeNode, CodamaError>>
fn resolve_type_directive( &self, _directive: &ResolvableDirective, _resolver: &dyn DirectiveResolver, ) -> Option<Result<RegisteredTypeNode, CodamaError>>
Try to resolve a resolvable type directive belonging to this plugin.
Returns
None if this plugin does not handle the given directive.Sourcefn resolve_value_directive(
&self,
_directive: &ResolvableDirective,
_resolver: &dyn DirectiveResolver,
) -> Option<Result<InstructionInputValueNode, CodamaError>>
fn resolve_value_directive( &self, _directive: &ResolvableDirective, _resolver: &dyn DirectiveResolver, ) -> Option<Result<InstructionInputValueNode, CodamaError>>
Try to resolve a resolvable value directive belonging to this plugin.
Returns
None if this plugin does not handle the given directive.Auto Trait Implementations
impl Freeze for TyphoonPlugin
impl RefUnwindSafe for TyphoonPlugin
impl Send for TyphoonPlugin
impl Sync for TyphoonPlugin
impl Unpin for TyphoonPlugin
impl UnsafeUnpin for TyphoonPlugin
impl UnwindSafe for TyphoonPlugin